# About

## Development

ScippNexus is an open source project by the [European Spallation Source ERIC](https://ess.eu/) (ESS).

## License

ScippNexus is available as open source under the [BSD-3 license](https://opensource.org/license/BSD-3-Clause).

## Citing ScippNexus

Please cite the following:

[![DOI](https://zenodo.org/badge/475453428.svg)](https://zenodo.org/doi/10.5281/zenodo.7408075)

To cite a specific version of ScippNexus, select the desired version on Zenodo to get the corresponding DOI.

## Older versions of the documentation

Older versions of the documentation pages can be found under the assets of each [release](https://github.com/scipp/scippnexus/releases).
Simply download the archive, unzip and view locally in a web browser.

## Source code and development

ScippNexus is hosted and developed [on GitHub](https://github.com/scipp/scippnexus).
